% Hinzufuegen eines Suchpfades fuer M-Files (falls erforderlich)
addpath '../routines/';
addpath '../examples/';

% Vektor mit Dimensionen der Matrix
v=[5 10 20 30 40 50 60 70 80 90 100];
zeit  =zeros(length(v),5);
fehler=zeros(length(v),5);
linienstil=['+'  'o'  '*'  'x'  's'];
farbe     =['g'  'r'  'y'  'c'  'm'];
menueeintrag{1}='MATLAB';
menueeintrag{2}='Gauss mit partieller Pivotisierung';
menueeintrag{3}='Vergleich aller';
menueeintrag{4}='Ende';

	    
k=menu('Auswahl der Algorithmen', menueeintrag);

while k<4

      mat=menu('Auswahl der Testmatrix',...
	       'zufaellig generiert',...
	       'Hilbertmatrix');
	   
      fprintf('Zeit fuer Loesung eines lin. Gls.\n');
      fprintf('Dim.');
      if k==1 | k==3
	 fprintf('|   MATLAB        ');
      end	           
      if (k==2 | k==3)
	 fprintf('|GAUSS, part. Piv.');
      end	           
      fprintf('\n');

      i=1;
      for n=v
	  if mat==1
	     % Beliebige Matrix der Dimension n
	     A=rand(n);
	  else
	     A=hilb(n);
	  end % if-else
	  % Beliebige Loesung 
	  x=rand(n,1);
	  % zugehoerige rechte Seite
	  b=A*x;
	  
	  % 1. Variante, eingebaute LU-Variante mittels 
	  if k==1 | k==3
	     t0=clock;
	     c=A\b;
	     zeit(i,1)=etime(clock,t0);
	     fehler(i,1)=norm(c-x)/norm(x);
	  end % if
	  
	  % 2. Variante, selbstgeschriebene LU-Variante 
	  if (k==2 | k==3)
	     B=A; 
	     t0=clock;    
	     % Gauss-Zerlegung
	     [B,piv]=GAUSSPLU(B);
	     % modifiziertes Vorwaertseinsetzen (Einheitsdiagonale)
	     c=b(piv,:);
	     c=FORWARD(B,piv,c); 
	     % Rueckwaertseinsetzen
	     c=BACKWARD(B,piv,c); 
	     zeit(i,2)=etime(clock,t0); 
	     fehler(i,2)=norm(c-x)/norm(x);  
	  end % if 

	  figure(1);
	  title('rel. Fehler zur vorgegebenen Loesung');
	  xlabel('n');
	  ylabel('rel. Fehler ||x-tilde{x}||/||x||');
	  if k<3
	     fprintf('----------------------\n');
	     semilogy(n,fehler(i,k),[linienstil(k) farbe(k)]);
	     hold on
	     fprintf('%4g|%12.4e\n', n, zeit(i,k));
	  else
	     fprintf('----------------------------------------\n');
	     for l=1:2
		 semilogy(n,fehler(i,l),[linienstil(l) farbe(l)]);
 	         hold on;
	     end % for
	     fprintf('%4g|   %12.4e  |   %12.4e\n', n, zeit(i,1),zeit(i,2));
	  end % if-else

	  figure(2);
	  title('Rechenzeit');
	  xlabel('n');
	  ylabel('[sec]');
	  if k<3
	     semilogy(n,zeit(i,k),[linienstil(k) farbe(k)]);
	     hold on
	  else
	     for l=1:2
		 semilogy(n,zeit(i,l),[linienstil(l) farbe(l)]);
 	         hold on;
	     end % for
	  end % if-else

	  i=i+1;
      end % for n  
       
      figure(1);
      title('Rechenzeit');
      xlabel('n');
      ylabel('[sec]');
      hold off;
      title('rel. Fehler zur vorgegebenen Loesung');
      xlabel('n');
      ylabel('rel. Fehler ||x-tilde{x}||/||x||');
      if k==1
	 legend('MATLAB');
      elseif k==2
	 legend('GAUSS mit part. Piv.');
      else
	 legend('MATLAB','GAUSS mit part. Piv.');
      end

      figure(2);
      hold off;
      title('Rechenzeit');
      xlabel('n');
      ylabel('[sec]');
      if k==1
	 legend('MATLAB');
      elseif k==2
	 legend('GAUSS mit part. Piv.');
      else
	 legend('MATLAB','GAUSS mit part. Piv.');
      end


      fprintf('\n');
       
       
      k=menu('Auswahl der Algorithmen', menueeintrag);
end % while

